@@ -75,6 +75,8 @@ def full_model_name(model,sep='.'):
     
 def obj2unicode(i):
     """Returns a user-friendly unicode representation of a model instance."""
+    if not isinstance(i,models.Model): 
+        return unicode(i)
     return u'%s "%s"' % (i._meta.verbose_name,unicode(i))
     
 def obj2str(i,force_detailed=False):
@@ -197,15 +199,16 @@ def monthname(n):
     d = datetime.date(2013,n,1)
     return defaultfilters.date(d,'F')
 
-def dtomy(d):
+def fdmy(d):
     """
-    "date to month/year" :
+    "format date as month and year" :
     return the specified date as a localized string of type 'June 2011'."""
     if d is None: return ''
     return defaultfilters.date(d,'F Y')
+    
+dtomy = fdmy # backward compat
 
-
-def set_language(lang=None):
+def unused_set_language(lang=None):
     """
     Thin wrapper around `django.utils.translation`.
     Activate the given language, or deactivate translations if 
